@@ -12,7 +12,7 @@ from hoover.utils import async_post_to_endpoint
 
 class LogglyHttpHandler(logging.Handler):
     def __init__(self, session=None, token='', inputname='', input=None,
-                 announce=False, json_class=None):
+                 announce=False, json_class=None, secure=True, proxy=None):
         logging.Handler.__init__(self)
         if inputname:
             # TODO: raise something appropriate if session is None
@@ -26,7 +26,9 @@ class LogglyHttpHandler(logging.Handler):
                 raise ValueError('This is not an HTTP input')
         session = session or LogglySession
         self.token = token
-        self.endpoint = "https://%s/inputs/%s" % (session.proxy, token)
+        protocol = secure and 'https' or 'http'
+        proxy = proxy or session.proxy
+        self.endpoint = "%s://%s/inputs/%s" % (protocol, proxy, token)
         self.json_class = json_class
         # TODO: verify we can write to the input
         if announce:
@@ -35,7 +37,7 @@ class LogglyHttpHandler(logging.Handler):
 
     def emit(self, record):
         if isinstance(record.msg, (list, dict)):
-            record.msg = dumps(record.msg, cls=self.json_class)
+            record.msg = dumps(record.msg, cls=self.json_class, default=str)
         msg = self.format(record)
         async_post_to_endpoint(self.endpoint, msg)
 
